from setuptools import setup

setup(
      name='MohamedSataryThirdTest',
      version='0.0.1',
      description='''Testing out uploading a library''',
      py_modules=['helloWorld'],
      package_dir={'': 'src'},
      )